==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/ko-KR/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => '장소 란',
    'about_locations'           => '장소는 사용자, 자산, 그리고 그외의 품목들에 대한 위치 정보 추적에 사용된다',
    'assets_rtd'                => '자산', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => '할당된 자산',
    'id'                        => '아이디',
    'city'                      => '시',
    'state'                     => '주',
    'country'                   => '국가명',
    'create'                    => '장소 생성',
    'update'                    => '장소 갱신',
    'print_assigned'            => '할당된 항목 인쇄',
    'print_all_assigned'        => '할당된 항목 모두 인쇄',
    'name'                      => '장소 명',
    'address'                   => '주소',
    'address2'                   => 'Address Line 2',
    'zip'                       => '우편번호',
    'locations'                 => '위치',
    'parent'                    => '상위',
    'currency'                  => '현지 통화',
    'ldap_ou'                   => 'LDAP 검색 OU',
    'user_name'                 => '사용자 이름',
    'department'                => '부서',
    'location'                  => '위치',
    'asset_tag'                 => '자산 태그',
    'asset_name'                => '이름',
    'asset_category'            => '항목',
    'asset_manufacturer'        => '제조사',
    'asset_model'               => '모델명',
    'asset_serial'              => '일련번호',
    'asset_location'            => '위치',
    'asset_checked_out'         => '반출 확인',
    'asset_expected_checkin'    => 'Expected Checkin',
    'date'                      => '날짜:',
    'phone'                     => 'Location Phone',
    'signed_by_asset_auditor'   => 'Signed By (Asset Auditor):',
    'signed_by_finance_auditor' => 'Signed By (Finance Auditor):',
    'signed_by_location_manager' => 'Signed By (Location Manager):',
    'signed_by'                 => 'Signed Off By:',
];

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/ko-KR/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => '장소 란',
    'about_locations'           => '장소는 사용자, 자산, 그리고 그외의 품목들에 대한 위치 정보 추적에 사용된다',
    'assets_rtd'                => '자산', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => '할당된 자산',
    'id'                        => '아이디',
    'city'                      => '시',
    'state'                     => '주',
    'country'                   => '국가명',
    'create'                    => '장소 생성',
    'update'                    => '장소 갱신',
    'print_assigned'            => '할당된 항목 인쇄',
    'print_all_assigned'        => '할당된 항목 모두 인쇄',
    'name'                      => '장소 명',
    'address'                   => '주소',
    'address2'                   => '두번재 주소',
    'zip'                       => '우편번호',
    'locations'                 => '위치',
    'parent'                    => '상위',
    'currency'                  => '현지 통화',
    'ldap_ou'                   => 'LDAP 검색 OU',
    'user_name'                 => '사용자 이름',
    'department'                => '부서',
    'location'                  => '위치',
    'asset_tag'                 => '자산 태그',
    'asset_name'                => '이름',
    'asset_category'            => '항목',
    'asset_manufacturer'        => '제조사',
    'asset_model'               => '모델명',
    'asset_serial'              => '일련번호',
    'asset_location'            => '위치',
    'asset_checked_out'         => '반출 확인',
    'asset_expected_checkin'    => 'Expected Checkin',
    'date'                      => '날짜:',
    'phone'                     => '유선번호',
    'signed_by_asset_auditor'   => 'Signed By (Asset Auditor):',
    'signed_by_finance_auditor' => 'Signed By (Finance Auditor):',
    'signed_by_location_manager' => 'Signed By (Location Manager):',
    'signed_by'                 => 'Signed Off By:',
];
